pub enum MaybeOwned<'a, T: 'a> {
    Owned(T),
    Borrowed(&'a T),
}

impl<'a, T: 'a> From<T> for MaybeOwned<'a, T> {
    fn from(value: T) -> Self {
        Self::Owned(value)
    }
}

impl<'a, T: 'a> From<&'a T> for MaybeOwned<'a, T> {
    fn from(value: &'a T) -> Self {
        Self::Borrowed(value)
    }
}

impl<'a, T: 'a + Default> Default for MaybeOwned<'a, T> {
    fn default() -> Self {
        MaybeOwned::Owned(T::default())
    }
}
